@@ -7,7 +7,7 @@ from cliff.command import Command
 class Run(Command):
     def get_parser(self, prog_name):
         parser = super(Run, self).get_parser(prog_name)
-        parser.add_argument("target", nargs=1, type=str, help="Hostname or address")
+        parser.add_argument("host", nargs=1, type=str, help="Hostname or address")
         parser.add_argument("environment", nargs=1, type=str, help="Environment")
         parser.add_argument(
             "arguments",
@@ -17,7 +17,7 @@ class Run(Command):
         return parser
 
     def take_action(self, parsed_args):
-        target_hostname = parsed_args.target[0]
+        host = parsed_args.host[0]
         environment = parsed_args.environment[0]
         arguments = "".join(parsed_args.arguments)
 
@@ -28,6 +28,6 @@ class Run(Command):
 
         # FIXME: use paramiko or something else more Pythonic + make operator user + key configurable
         subprocess.call(
-            f"/usr/bin/ssh -i /ansible/secrets/id_rsa.operator {ssh_options} dragon@{target_hostname} '{ssh_command}'",
+            f"/usr/bin/ssh -i /ansible/secrets/id_rsa.operator {ssh_options} dragon@{host} '{ssh_command}'",
             shell=True,
         )
