@@ -33,6 +33,12 @@ class Images(Command):
         parser.add_argument(
             "--cloud", type=str, help="Cloud name in clouds.yaml", default="openstack"
         )
+        parser.add_argument(
+            "--hypervisor",
+            type=str,
+            help="Set hypervisor type meta information",
+            default=None,
+        )
         parser.add_argument(
             "--filter",
             type=str,
@@ -53,6 +59,7 @@ class Images(Command):
         dry_run = parsed_args.dry_run
         filter = parsed_args.filter
         hide = parsed_args.hide
+        hypervisor = parsed_args.hypervisor
         latest = parsed_args.latest
         names = parsed_args.name
 
@@ -67,6 +74,8 @@ class Images(Command):
             arguments.append("--latest")
         if hide:
             arguments.append("--hide")
+        if hypervisor:
+            arguments.append(f"--hypervisor '{hypervisor}'")
         if names:
             for name in names:
                 arguments.append(f"--name '{name}'")
